# Mixin Updater

A simple helper to automatically update mixin binary from the latest GitHub release.

```
go get -u github.com/MixinNetwork/mixin/cmd/update-mixin
update-mixin -bin mixin-binary-directory
```
